package main

import (
	"encoding/json"
	"flag"
	"fmt"
	"os"
)

type Config struct {
	MinifluxURL      string `json:"miniflux_url"`
	MinifluxAPI      string `json:"miniflux_api"`
	MinifluxCategory string `json:"miniflux_category"`
}

func (c *Config) IsValid() error {
	return nil
}

func ReadConfig(name string) (*Config, error) {
	b, err := os.ReadFile(name)
	if err != nil {
		return nil, err
	}

	var cfg Config
	if err := json.Unmarshal(b, &cfg); err != nil {
		return nil, err
	}

	return &cfg, nil
}

func checkErr(err error) {
	if err != nil {
		fmt.Fprintf(os.Stderr, "error: %s\n", err)
		os.Exit(1)
	}
}

func main() {
	cfgFlag := flag.String("config", "bookworm.json", "path to the configuration file")
	flag.Parse()

	cfg, err := ReadConfig(*cfgFlag)
	checkErr(err)

	cErr := cfg.IsValid()
	checkErr(cErr)
}
